==> moodle-1.5-pgsql.tgz: moodle/lang/pt_br/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.4.3 (2004083130)


$string['calendar'] = 'Calendrio';
$string['calendarheading'] = '$a Calendrio';
$string['clickhide'] = 'clique para esconder';
$string['clickshow'] = 'Clique para mostrar';
$string['confirmeventdelete'] = 'Voc tem certeza que quer cancelar este evento?';
$string['courseevents'] = 'Eventos do curso';
$string['day'] = 'Dia';
$string['dayview'] = 'Visualizar Dia';
$string['daywithnoevents'] = 'No h eventos neste dia.';
$string['default'] = 'Predefinido';
$string['deleteevent'] = 'Cancelar evento';
$string['detailedmonthview'] = 'Visualizar ms em detalhes';
$string['dstadjusttime'] = 'Mover horrio';
$string['dstat'] = 'em';
$string['dstby'] = 'por';
$string['dstdefaultpresetname'] = 'Nova configurao predefinida de DST';
$string['dsthumanreadable'] = 'No $a->activate_index $a->activate_weekday de cada $a->activate_month, alterar o orrio assim:  $a->offset minutos $a->direction. Esta alterao provisria dura at o $a->deactivate_index $a->deactivate_weekday de $a->deactivate_month.';
$string['dstof'] = 'de';
$string['dstonthe'] = 'Em';
$string['dstpresetactivated'] = 'Ativao';
$string['dstpresetadjusttime'] = 'Correo do orrio';
$string['dstpresetdeactivated'] = 'Desativao';
$string['dstpresetname'] = 'Nome da configurao predefinida';
$string['durationminutes'] = 'Durao em minutos';
$string['durationnone'] = 'Sem durao';
$string['durationuntil'] = 'At';
$string['editevent'] = 'Editando evento';
$string['errorbeforecoursestart'] = 'No  possivel definir um evento anterior  data inicial do curso';
$string['errorinvaliddate'] = 'Data no vlida';
$string['errorinvalidminutes'] = 'Definir durao em minutos utilizando uma numerao entre 1 e 999.';
$string['errorinvalidrepeats'] = 'Definir numero de eventos utilizando uma numerao entre 1 e 99.';
$string['errornodescription'] = ' necessria uma descrio';
$string['errornoeventname'] = ' necessrio um nome';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Descrio';
$string['eventduration'] = 'Durao';
$string['eventendtime'] = 'Hora final';
$string['eventinstanttime'] = 'Hora';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nome';
$string['eventrepeat'] = 'Repetio';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora inicial';
$string['eventtime'] = 'Hora';
$string['eventview'] = 'Detalhes do evento';
$string['expired'] = 'Terminado';
$string['explain_dstpreset'] = 'Voc pode selecionar a rea em que ser utilizada a configurao do DST, se presente, utilizando o men drop-down';
$string['explain_dstpresetforced'] = 'Atualmente no  permitido modificar esta opo.';
$string['explain_lookahead'] = 'Define um nmero mximo de dias correspondente ao intervallo em que um evento futuro ser considerado com Evento Prximo. Os eventos che iniciam depois deste periodo no sero considerados como eventos prximos. Se o nmero de eventos prximos for muito grande, o nmero de eventos visualizados ser limitado em funo da configurao do Nmero mximo de eventos prximos';
$string['explain_maxevents'] = 'Define o numero mximo de Prximos Eventos visualizados. Escolha um nmero pequeno para evitar a visualizao de um nmero excessivo de dados.';
$string['explain_startwday'] = 'As semanas mostradas comeam no dia indicado aqui.';
$string['explain_timeformat'] = 'Voc pode escolher o formato de visualizao das horas: intervalos de 12 ou 24 horas. Escolhendo a opo predefinida os paramtros utilizados sero aqueles definidos para o idioma do site.';
$string['first'] = 'primeiro';
$string['fri'] = 'Sex';
$string['friday'] = 'Sexta-feira';
$string['globalevents'] = 'Eventos globais';
$string['gotocalendar'] = 'Calendrio';
$string['groupevents'] = 'Eventos do grupo';
$string['hidden'] = 'Escondido';
$string['last'] = 'ltimo';
$string['manyevents'] = '$a eventos';
$string['mon'] = 'Seg';
$string['monday'] = 'Segunda-feira';
$string['monthlyview'] = 'Visualizar ms';
$string['newevent'] = 'Novo evento';
$string['notusingdst'] = 'No est usando o DST';
$string['noupcomingevents'] = 'No h nenhum evento prximo';
$string['nth'] = '{$a}st';
$string['oneevent'] = '1 evento';
$string['pref_dstpreset'] = 'Horrio de vero';
$string['pref_lookahead'] = 'Previso de prximos eventos';
$string['pref_maxevents'] = 'Nmero mximo de prximos eventos ';
$string['pref_startwday'] = 'primeiro dia da semana';
$string['pref_timeformat'] = 'Formato de visualizao da hora';
$string['preferences'] = 'Preferncias';
$string['preferences_available'] = 'As suas preferncias';
$string['repeatnone'] = 'Nenhuma repetio';
$string['repeatweeksl'] = 'Repetir semanalmente, criar todas de uma vez';
$string['repeatweeksr'] = 'eventos';
$string['sat'] = 'Sb';
$string['saturday'] = 'Sbado';
$string['shown'] = 'mostrados';
$string['spanningevents'] = 'Eventos em curso';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Qui';
$string['thursday'] = 'Quinta-feira';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['timeforward'] = 'avante';
$string['timerewind'] = 'atrs';
$string['today'] = 'Hoje';
$string['tomorrow'] = 'Amanh';
$string['tt_deleteevent'] = 'Cancelar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Eventos do curso esto visveis (clique para esconder)';
$string['tt_hideglobal'] = 'Eventos globais esto visveis (clique para esconder)';
$string['tt_hidegroups'] = 'Eventos do grupo esto visveis (clique para esconder)';
$string['tt_hideuser'] = 'Eventos do usurio esto visveis (clique para esconder)';
$string['tt_showcourse'] = 'Eventos do curso esto ocultos (clique para mostrar)';
$string['tt_showglobal'] = 'Eventos globais esto ocultos (clique para mostrar)';
$string['tt_showgroups'] = 'Eventos do grupo esto ocultos (clique para mostrar)';
$string['tt_showuser'] = 'Eventos do usurio esto ocultos (clique para mostrar)';
$string['tue'] = 'Ter';
$string['tuesday'] = 'Tera-feira';
$string['typecourse'] = 'Evento do curso';
$string['typegroup'] = 'Evento do grupo';
$string['typesite'] = 'Evento do site';
$string['typeuser'] = 'Evento do usurio';
$string['upcomingevents'] = 'Prximos Eventos';
$string['userevents'] = 'Eventos do usurio';
$string['wed'] = 'Qua';
$string['wednesday'] = 'Quarta-feira';
$string['yesterday'] = 'ontem';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/pt_br/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 + (2005060201)


$string['calendar'] = 'Calendrio';
$string['calendarheading'] = '$a Calendrio';
$string['clickhide'] = 'clique para esconder';
$string['clickshow'] = 'clique para mostrar';
$string['confirmeventdelete'] = 'Voc tem certeza que quer cancelar este evento?';
$string['courseevents'] = 'Eventos do curso';
$string['dayview'] = 'Visualizar Dia';
$string['daywithnoevents'] = 'No h eventos neste dia.';
$string['default'] = 'Predefinido';
$string['deleteevent'] = 'Cancelar evento';
$string['detailedmonthview'] = 'Visualizar ms em detalhes';
$string['durationminutes'] = 'Durao em minutos';
$string['durationnone'] = 'Sem durao';
$string['durationuntil'] = 'At';
$string['editevent'] = 'Editando evento';
$string['errorbeforecoursestart'] = 'No  possivel definir um evento anterior  data inicial do curso';
$string['errorinvaliddate'] = 'Data no vlida';
$string['errorinvalidminutes'] = 'Definir durao em minutos utilizando uma numerao entre 1 e 999.';
$string['errorinvalidrepeats'] = 'Definir numero de eventos utilizando uma numerao entre 1 e 99.';
$string['errornodescription'] = ' necessria uma descrio';
$string['errornoeventname'] = ' necessrio um nome';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Descrio';
$string['eventduration'] = 'Durao';
$string['eventendtime'] = 'Hora final';
$string['eventinstanttime'] = 'Hora';
$string['eventkind'] = 'Tipo de evento';
$string['eventname'] = 'Nome';
$string['eventrepeat'] = 'Repetio';
$string['eventsfor'] = '$a eventos';
$string['eventstarttime'] = 'Hora inicial';
$string['eventtime'] = 'Hora';
$string['eventview'] = 'Detalhes do evento';
$string['expired'] = 'Terminado';
$string['explain_lookahead'] = 'Define um nmero mximo de dias correspondente ao intervallo em que um evento futuro ser considerado com Evento Prximo. Os eventos che iniciam depois deste periodo no sero considerados como eventos prximos. Se o nmero de eventos prximos for muito grande, o nmero de eventos visualizados ser limitado em funo da configurao do Nmero mximo de eventos prximos';
$string['explain_maxevents'] = 'Define o numero mximo de Prximos Eventos visualizados. Escolha um nmero pequeno para evitar a visualizao de um nmero excessivo de dados.';
$string['explain_persistflt'] = 'Se isto for ativado, o sistema recorda as ltimas configuraes do seu filtro de eventos e reconstroe as mesmas cada vez que voc fizer o login.';
$string['explain_startwday'] = 'As semanas mostradas comeam no dia indicado aqui.';
$string['explain_timeformat'] = 'Voc pode escolher o formato de visualizao das horas: intervalos de 12 ou 24 horas. Escolhendo a opo predefinida os paramtros utilizados sero aqueles definidos para o idioma do site.';
$string['fri'] = 'Sex';
$string['friday'] = 'Sexta-feira';
$string['globalevents'] = 'Eventos globais';
$string['gotocalendar'] = 'Calendrio';
$string['groupevents'] = 'Eventos do grupo';
$string['hidden'] = 'Escondido';
$string['manyevents'] = '$a eventos';
$string['mon'] = 'Seg';
$string['monday'] = 'Segunda-feira';
$string['monthlyview'] = 'Visualizar ms';
$string['newevent'] = 'Novo evento';
$string['noupcomingevents'] = 'No h nenhum evento prximo';
$string['oneevent'] = '1 evento';
$string['pref_lookahead'] = 'Previso de prximos eventos';
$string['pref_maxevents'] = 'Nmero mximo de prximos eventos ';
$string['pref_persistflt'] = 'Lembrar configurao dos filtros';
$string['pref_startwday'] = 'primeiro dia da semana';
$string['pref_timeformat'] = 'Formato de visualizao da hora';
$string['preferences'] = 'Preferncias';
$string['preferences_available'] = 'As suas preferncias';
$string['repeateditall'] = 'Aplicar alteraes a todos os $a eventos desta srie de repeties';
$string['repeateditthis'] = 'Aplicar mudanas apenas a este evento';
$string['repeatnone'] = 'Nenhuma repetio';
$string['repeatweeksl'] = 'Repetir semanalmente, criar todas de uma vez';
$string['repeatweeksr'] = 'eventos';
$string['sat'] = 'Sb';
$string['saturday'] = 'Sbado';
$string['shown'] = 'mostrados';
$string['spanningevents'] = 'Eventos em curso';
$string['sun'] = 'Dom';
$string['sunday'] = 'Domingo';
$string['thu'] = 'Qui';
$string['thursday'] = 'Quinta-feira';
$string['timeformat_12'] = '12 horas (am/pm)';
$string['timeformat_24'] = '24 horas';
$string['today'] = 'Hoje';
$string['tomorrow'] = 'Amanh';
$string['tt_deleteevent'] = 'Cancelar evento';
$string['tt_editevent'] = 'Editar evento';
$string['tt_hidecourse'] = 'Eventos do curso esto visveis (clique para esconder)';
$string['tt_hideglobal'] = 'Eventos globais esto visveis (clique para esconder)';
$string['tt_hidegroups'] = 'Eventos do grupo esto visveis (clique para esconder)';
$string['tt_hideuser'] = 'Eventos do usurio esto visveis (clique para esconder)';
$string['tt_showcourse'] = 'Eventos do curso esto ocultos (clique para mostrar)';
$string['tt_showglobal'] = 'Eventos globais esto ocultos (clique para mostrar)';
$string['tt_showgroups'] = 'Eventos do grupo esto ocultos (clique para mostrar)';
$string['tt_showuser'] = 'Eventos do usurio esto ocultos (clique para mostrar)';
$string['tue'] = 'Ter';
$string['tuesday'] = 'Tera-feira';
$string['typecourse'] = 'Evento do curso';
$string['typegroup'] = 'Evento do grupo';
$string['typesite'] = 'Evento do site';
$string['typeuser'] = 'Evento do usurio';
$string['upcomingevents'] = 'Prximos Eventos';
$string['userevents'] = 'Eventos do usurio';
$string['wed'] = 'Qua';
$string['wednesday'] = 'Quarta-feira';
$string['yesterday'] = 'Ontem';
$string['youcandeleteallrepeats'] = 'Este evento  parte de uma srie de eventos repetidos. Voc pode cancelar apenas este evento ou todos os $a eventos de uma vez s.';

?>
